"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.uiWorkshop = void 0;
const inject_1 = require("../actions/inject");
const package_1 = require("../npm/package");
const log_1 = __importDefault(require("../util/log"));
const chalk_1 = __importDefault(require("chalk"));
const outdent_1 = __importDefault(require("outdent"));
const resolveLatestVersions_1 = require("../npm/resolveLatestVersions");
const path_1 = __importDefault(require("path"));
const files_1 = require("../util/files");
const errorToUndefined_1 = require("../util/errorToUndefined");
exports.uiWorkshop = {
    name: 'ui-workshop',
    description: 'Files for testing custom components with @sanity/ui-workshop',
    apply: applyPreset,
};
function applyPreset(options) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, inject_1.writeAssets)(files(), options);
        yield addDevDependencies(options);
        yield updateGitIgnore(options);
        log_1.default.info(chalk_1.default.green((0, outdent_1.default) `
        ui-workshop preset injected.

        Please confer
        https://github.com/sanity-io/plugin-kit/blob/main/docs/ui-workshop.md#manual-steps-after-inject
        to finalize configuration for this preset.
  `.trim()));
    });
}
function files() {
    return [
        { from: ['workshop.config.ts'], to: ['workshop.config.ts'] },
        { from: ['src', 'CustomField.tsx'], to: ['src', 'CustomField.tsx'] },
        { from: ['src', '__workshop__', 'index.tsx'], to: ['src', '__workshop__', 'index.tsx'] },
        { from: ['src', '__workshop__', 'props.tsx'], to: ['src', '__workshop__', 'props.tsx'] },
    ].map((fromTo) => (Object.assign(Object.assign({}, fromTo), { from: ['ui-workshop', ...fromTo.from] })));
}
function updateGitIgnore(options) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const { basePath } = options;
        const gitignorePath = path_1.default.join(basePath, '.gitignore');
        let gitignore = (_a = (yield (0, files_1.readFile)(gitignorePath, 'utf8').catch(errorToUndefined_1.errorToUndefined))) !== null && _a !== void 0 ? _a : '';
        const value = '.workshop';
        if (gitignore.includes(value)) {
            return;
        }
        gitignore += `\n\n${value}`;
        yield (0, files_1.writeFile)(gitignorePath, gitignore, { encoding: 'utf8' });
    });
}
function addDevDependencies(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield (0, package_1.getPackage)(options);
        const devDeps = (0, package_1.sortKeys)(Object.assign(Object.assign({}, pkg.devDependencies), (yield devDependencies())));
        const newPkg = Object.assign({}, pkg);
        newPkg.devDependencies = devDeps;
        yield (0, package_1.writePackageJsonDirect)(newPkg, options);
        log_1.default.info('Updated devDependencies.');
    });
}
function devDependencies() {
    return __awaiter(this, void 0, void 0, function* () {
        return (0, resolveLatestVersions_1.resolveLatestVersions)([
            '@sanity/ui-workshop',
            '@sanity/icons',
            '@sanity/ui',
            'react',
            'react-dom',
            'styled-component',
        ]);
    });
}
//# sourceMappingURL=ui-workshop.js.map